#
# spec file for package openstack-freezer
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel} || 0%{?fedora}
%global rdo 1
%endif
Name:           openstack-freezer
Version:        6.0.1~dev5
Release:        2.1
Summary:        OpenStack Backup and Restore
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://launchpad.net/freezer
Source0:        freezer-stable-queens.tar.gz
Source1:        openstack-freezer.logrotate
Source2:        openstack-freezer-scheduler.service
BuildRequires:  openstack-macros
BuildRequires:  openstack-tempest
BuildRequires:  python-APScheduler
BuildRequires:  python-Babel
BuildRequires:  python-PyMySQL
BuildRequires:  python-botocore
BuildRequires:  python-cinderclient
BuildRequires:  python-ddt
BuildRequires:  python-fixtures
BuildRequires:  python-freezerclient
BuildRequires:  python-glanceclient
BuildRequires:  python-keystoneauth1
BuildRequires:  python-keystoneclient
BuildRequires:  python-mock
BuildRequires:  python-neutronclient
BuildRequires:  python-novaclient
BuildRequires:  python-os-brick
BuildRequires:  python-oslo.config
BuildRequires:  python-oslo.log
BuildRequires:  python-oslo.service
BuildRequires:  python-oslo.utils
BuildRequires:  python-paramiko
BuildRequires:  python-pbr
BuildRequires:  python-psutil
BuildRequires:  python-pycrypto
BuildRequires:  python-pymongo
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  python-swiftclient
Requires:       python-freezer = %{version}-%{release}
BuildArch:      noarch
%if 0%{?suse_version}
BuildRequires:  systemd-rpm-macros
Requires(pre):  pwdutils
%{?systemd_requires}
%endif
%if 0%{?rdo}
BuildRequires:  systemd
Requires(post): systemd
Requires(postun): systemd
Requires(pre):  shadow-utils
Requires(preun): systemd
%endif

%description
OpenStack Swift incremental backup and restore automation tool for
file system, MongoDB, MySQL. LVM snapshot and encryption support.

%package -n     python-freezer
Summary:        Freezer Python libraries
Group:          Applications/System
Requires:       python-APScheduler
Requires:       python-Babel
Requires:       python-PyMySQL
Requires:       python-botocore
Requires:       python-cinderclient
Requires:       python-freezerclient
Requires:       python-glanceclient
Requires:       python-keystoneauth1
Requires:       python-keystoneclient
Requires:       python-neutronclient
Requires:       python-novaclient
Requires:       python-os-brick
Requires:       python-oslo.config
Requires:       python-oslo.log
Requires:       python-oslo.service
Requires:       python-oslo.utils
Requires:       python-paramiko
Requires:       python-psutil
Requires:       python-pycrypto
Requires:       python-pymongo
Requires:       python-six
Requires:       python-swiftclient

%description -n python-freezer
OpenStack Swift incremental backup and restore automation tool for
file system, MongoDB, MySQL. LVM snapshot and encryption support.

This package contains the Freezer python libraries.

%package agent
Summary:        OpenStack Freezer - Agent service
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}

%description agent
OpenStack Swift incremental backup and restore automation tool for
file system, MongoDB, MySQL. LVM snapshot and encryption support.

This package contains the Freezer agent code.

%package scheduler
Summary:        OpenStack Freezer - Scheduler service
Group:          Applications/System
Requires:       %{name} = %{version}-%{release}

%description scheduler
OpenStack Swift incremental backup and restore automation tool for
file system, MongoDB, MySQL. LVM snapshot and encryption support.

This package contains the Freezer scheduler agent.

%package doc
Summary:        Documentation for OpenStack Backup Service
Group:          Documentation/HTML
BuildRequires:  fdupes
BuildRequires:  python-Sphinx
BuildRequires:  python-openstackdocstheme

%description doc
OpenStack Freezer documentaion.

This package contains the documentation

%prep
%autosetup -p1 -n freezer-6.0.1.dev5
%py_req_cleanup
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%{py2_build}

#NOTE(aplanas): The manual page cannot be generated yet
%{__python2} setup.py build_sphinx --builder=html
# remove the Sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}
%fdupes doc/build/html/
# config file generation
PYTHONPATH=. oslo-config-generator --config-file config-generator/scheduler.conf \
    --output-file etc/scheduler.conf.sample

%install
%{py2_install}
install -d -m 755 %{buildroot}%{_sysconfdir}/freezer
install -d -m 755 %{buildroot}%{_localstatedir}/{lib,log}/freezer
install -d -m 755 %{buildroot}%{_sysconfdir}/freezer/freezer.conf.d/
install -d -m 750 %{buildroot}%{_sysconfdir}/freezer/scheduler/
install -d -m 750 %{buildroot}%{_sysconfdir}/freezer/scheduler/conf.d/
install -p -D -m 640 etc/scheduler.conf.sample %{buildroot}%{_sysconfdir}/freezer/scheduler.conf
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/openstack-freezer
install -p -D -m 755 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}-scheduler.service

# remove duplicates
%fdupes %{buildroot}%{python2_sitelib}

# remove Windows script
rm -fr %{buildroot}%{_prefix}/freezer/scripts/vss.ps1

%pre
%openstack_pre_user_group_create freezer freezer /sbin/nologin

#POST actions
%post scheduler
%systemd_post %{name}-scheduler.service

#PREUN actions
%preun scheduler
%systemd_preun %{name}-scheduler.service

#POSTUN actions
%postun scheduler
%systemd_postun_with_restart %{name}-scheduler.service

%check
OS_TEST_PATH=./freezer/tests/unit python setup.py testr

%files
%license LICENSE
%doc README.rst
%dir %attr(0750, root, freezer) %{_sysconfdir}/freezer/
%dir %attr(0750, root, freezer) %{_sysconfdir}/freezer/freezer.conf.d/
%dir %attr(0750, root, freezer) %{_sysconfdir}/freezer/scheduler/
%dir %attr(0750, root, freezer) %{_sysconfdir}/freezer/scheduler/conf.d/
%config(noreplace) %attr(0640, root, freezer) %{_sysconfdir}/freezer/scheduler.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/openstack-freezer
%dir %attr(0755, freezer, freezer) %{_localstatedir}/lib/freezer
%dir %attr(0750, freezer, freezer) %{_localstatedir}/log/freezer

%files -n python-freezer
%defattr(-,root,root,-)
%doc README.rst
%license LICENSE
%{python2_sitelib}/freezer*
%{python2_sitelib}/freezer-*.egg-info

%files agent
%license LICENSE
%{_bindir}/freezer-agent

%files scheduler
%license LICENSE
%{_bindir}/freezer-scheduler
%{_unitdir}/%{name}-scheduler.service

%files doc
%license LICENSE
%doc doc/build/html

%changelog
